@@ -94,7 +94,7 @@ def pop(path,
     file_names = sorted(Path(path).glob('*.out'))
     for file_name in file_names:
         with InputXmlFileReader(file_name, physical_quantities) as xml_file:
-            print(f'{xml_file.name}:')
+            print(f'{xml_file.out_name}:')
             print(f'found:     {xml_file.fetched_physical_quantity}')
             print(f'not found: {xml_file.unfetched_physical_quantity}')
             print()
